@@ -12,11 +12,11 @@
 #'        TIGER/Line file).
 #' @param resolution The resolution of the cartographic boundary file (if cb == TRUE).
 #'        Defaults to '500k'; options include '5m' (1:5 million) and '20m' (1:20 million).
-#' @param year the data year (defaults to 2018).
+#' @param year the data year (defaults to 2019).
 #' @param ... arguments to be passed to the underlying `load_tiger` function, which is not exported.
-#'        Options include \code{class}, which can be set to \code{"sp"} (the default) or \code{"sf"} to
-#'        request sp or sf class objects, and \code{refresh}, which specifies whether
-#'        or not to re-download shapefiles (defaults to \code{FALSE}).
+#'        Options include \code{class}, which can be set to \code{"sf"} (the default) or \code{"sp"} to
+#'        request sf or sp class objects, and \code{refresh}, which specifies whether or
+#'        not to re-download shapefiles (defaults to \code{FALSE}).
 #' @family legislative district functions
 #' @seealso \url{https://www.census.gov/programs-surveys/geography/guidance/geo-areas/congressional-dist.html}
 #' @export
@@ -34,10 +34,15 @@ congressional_districts <- function(cb = FALSE, resolution = '500k', year = NULL
 
   if (is.null(year)) {
 
-    year <- getOption("tigris_year", 2017)
+    year <- getOption("tigris_year", 2019)
 
   }
 
+  if (year < 2013 && cb == TRUE) {
+    stop("`cb = TRUE` for congressional districts is unavailable prior to 2013. Regular TIGER/Line files are available for 2010 through 2010 with `cb = FALSE`",
+         call. = FALSE)
+  }
+
   if (year %in% 2018:2019) {
     congress <- "116"
   } else if (year %in% 2016:2017) {
@@ -48,14 +53,15 @@ congressional_districts <- function(cb = FALSE, resolution = '500k', year = NULL
     congress <- "113"
   } else if (year %in% 2011:2012) {
     congress <- "112"
+  } else if (year == 2010) {
+    congress <- "111"
   }
 
-  if (year < 2011) {
+  if (year < 2010) {
 
     fname <- as.character(match.call())[[1]]
 
-    msg <- sprintf("%s is not currently available for years prior to 2011.  To request this feature,
-                   file an issue at https://github.com/walkerke/tigris.", fname)
+    msg <- sprintf("%s is not currently available for years prior to 2010.", fname)
 
     stop(msg, call. = FALSE)
 
@@ -102,9 +108,9 @@ congressional_districts <- function(cb = FALSE, resolution = '500k', year = NULL
 #'        TIGER/Line file).
 #' @param year the data year (defaults to 2017).
 #' @param ... arguments to be passed to the underlying `load_tiger` function, which is not exported.
-#'        Options include \code{class}, which can be set to \code{"sp"} (the default) or \code{"sf"} to
-#'        request sp or sf class objects, and code{refresh}, which specifies whether or not to re-download
-#'        shapefiles (defaults to \code{FALSE}).
+#'        Options include \code{class}, which can be set to \code{"sf"} (the default) or \code{"sp"} to
+#'        request sf or sp class objects, and \code{refresh}, which specifies whether or
+#'        not to re-download shapefiles (defaults to \code{FALSE}).
 #' @family legislative district functions
 #' @seealso \url{https://www.census.gov/programs-surveys/geography/guidance/geo-areas/state-legis-dist.html}
 #' @export
@@ -124,7 +130,7 @@ state_legislative_districts <- function(state, house = "upper", cb = FALSE, year
 
   if (is.null(year)) {
 
-    year <- getOption("tigris_year", 2017)
+    year <- getOption("tigris_year", 2019)
 
   }
 
@@ -209,9 +215,9 @@ state_legislative_districts <- function(state, house = "upper", cb = FALSE, year
 #' @param state The state for which you'd like to retrieve data.  Can be a state name,
 #'        state abbreviation, or FIPS code.
 #' @param ... arguments to be passed to the underlying `load_tiger` function, which is not exported.
-#'        Options include \code{class}, which can be set to \code{"sp"} (the default) or \code{"sf"} to
-#'        request sp or sf class objects, and \code{refresh}, which specifies whether or not
-#'        to re-download shapefiles (defaults to \code{FALSE}).
+#'        Options include \code{class}, which can be set to \code{"sf"} (the default) or \code{"sp"} to
+#'        request sf or sp class objects, and \code{refresh}, which specifies whether or
+#'        not to re-download shapefiles (defaults to \code{FALSE}).
 #'
 #' @family legislative district functions
 #' @export
@@ -221,7 +227,7 @@ state_legislative_districts <- function(state, house = "upper", cb = FALSE, year
 #'
 #' ia <- voting_districts("Iowa")
 #'
-#' plot(ia)
+#' plot(ia$geometry)
 #'
 #' }
 voting_districts <- function(state, ...) {
