@@ -10,28 +10,27 @@
 #'        (case-insensitive).
 #' @param county The three-digit FIPS code of the county you'd like the water
 #'        features for.  Can also be a county name.
-#' @param year the data year (defaults to 2018).
+#' @param year the data year (defaults to 2019).
 #' @param ... arguments to be passed to the underlying `load_tiger` function, which is not exported.
-#'        Options include \code{class}, which can be set to \code{"sp"} (the default) or \code{"sf"} to
-#'        request sp or sf class objects, and \code{refresh}, which specifies whether or
-#'        not to re-download shapefiles (defaults to \code{FALSE}).).
+#'        Options include \code{class}, which can be set to \code{"sf"} (the default) or \code{"sp"} to
+#'        request sf or sp class objects, and \code{refresh}, which specifies whether or
+#'        not to re-download shapefiles (defaults to \code{FALSE}).
 #' @family water functions
-#' @seealso \url{http://www2.census.gov/geo/pdfs/maps-data/data/tiger/tgrshp2018/TGRSHP2018_TechDoc.pdf}
+#' @seealso \url{http://www2.census.gov/geo/pdfs/maps-data/data/tiger/tgrshp2019/TGRSHP2019_TechDoc.pdf}
 #' @export
 #' @examples \dontrun{
 #' library(tigris)
-#' library(sp)
 #'
 #' dallas_water <- area_water("TX", "Dallas")
 #'
-#' plot(dallas_water)
+#' plot(dallas_water$geometry)
 #'
 #' }
 area_water <- function(state, county, year = NULL, ...) {
 
   if (is.null(year)) {
 
-    year <- getOption("tigris_year", 2018)
+    year <- getOption("tigris_year", 2019)
 
   }
 
@@ -46,6 +45,15 @@ area_water <- function(state, county, year = NULL, ...) {
 
   }
 
+  if (length(county) > 1) {
+    w <- lapply(county, function(x) {
+      area_water(state = state, county = x, year = year, ...)
+    }) %>%
+      rbind_tigris()
+
+    return(w)
+  }
+
   state <- validate_state(state)
 
   county <- validate_county(state, county)
@@ -77,28 +85,27 @@ area_water <- function(state, county, year = NULL, ...) {
 #'        (case-insensitive).
 #' @param county The three-digit FIPS code of the county you'd like the water
 #'        features for.  Can also be a county name.
-#' @param year the data year (defaults to 2018).
+#' @param year the data year (defaults to 2019).
 #' @param ... arguments to be passed to the underlying `load_tiger` function, which is not exported.
-#'        Options include \code{class}, which can be set to \code{"sp"} (the default) or \code{"sf"} to
-#'        request sp or sf class objects, and \code{refresh}, which specifies whether or
-#'        not to re-download shapefiles (defaults to \code{FALSE}).).
+#'        Options include \code{class}, which can be set to \code{"sf"} (the default) or \code{"sp"} to
+#'        request sf or sp class objects, and \code{refresh}, which specifies whether or
+#'        not to re-download shapefiles (defaults to \code{FALSE}).
 #' @family water functions
-#' @seealso \url{http://www2.census.gov/geo/pdfs/maps-data/data/tiger/tgrshp2018/TGRSHP2018_TechDoc.pdf}
+#' @seealso \url{http://www2.census.gov/geo/pdfs/maps-data/data/tiger/tgrshp2019/TGRSHP2019_TechDoc.pdf}
 #' @export
 #' @examples \dontrun{
 #' library(tigris)
-#' library(sp)
 #'
 #' dallas_water <- linear_water("TX", "Dallas")
 #'
-#' plot(dallas_water)
+#' plot(dallas_water$geometry)
 #'
 #' }
 linear_water <- function(state, county, year = NULL, ...) {
 
   if (is.null(year)) {
 
-    year <- getOption("tigris_year", 2018)
+    year <- getOption("tigris_year", 2019)
 
   }
 
@@ -113,6 +120,15 @@ linear_water <- function(state, county, year = NULL, ...) {
 
   }
 
+  if (length(county) > 1) {
+    w <- lapply(county, function(x) {
+      linear_water(state = state, county = x, year = year, ...)
+    }) %>%
+      rbind_tigris()
+
+    return(w)
+  }
+
   state <- validate_state(state)
 
   county <- validate_county(state, county)
@@ -132,46 +148,18 @@ linear_water <- function(state, county, year = NULL, ...) {
 
 #' Download a shapefile of the US coastline into R
 #'
-#' @param year The year of the dataset (defaults to 2018)
+#' @param year The year of the dataset (defaults to 2019)
 #' @param ... arguments to be passed to the underlying `load_tiger` function, which is not exported.
 #'        Options include \code{class}, which can be set to \code{"sp"} (the default) or \code{"sf"} to
 #'        request sp or sf class objects, and \code{refresh}, which specifies whether or
 #'        not to re-download shapefiles (defaults to \code{FALSE}).).
 #' @export
 #' @family water functions
-#' @examples \dontrun{
-#' library(tigris)
-#' library(ggplot2)
-#' library(ggthemes)
-#' library(rgeos)
-#' library(sp)
-#'
-#' coast <- coastline()
-#'
-#' # ggplot really doesn't like a ton of detailed lines so
-#' # we use rgeos::gSimplify to get the structure to a reasonable size
-#' # but we also lose the SpatialLinesDataFrame, so re-bind the
-#' # data from the original spatial structure so we can use fortify
-#'
-#' coast_simp <- gSimplify(coast, tol=1/200, topologyPreserve=TRUE)
-#' coast_simp <- SpatialLinesDataFrame(coast_simp, coast@@data)
-#'
-#' coast_map <- fortify(coast_simp)
-#'
-#' gg <- ggplot()
-#' gg <- gg + geom_map(data=coast_map, map=coast_map,
-#'                     aes(x=long, y=lat, map_id=id),
-#'                     color="black", fill="white", size=0.25)
-#' gg <- gg + coord_map(xlim=c(-125.0011, -66.9326),
-#'                      ylim=c(24.9493, 49.5904))
-#' gg <- gg + theme_map()
-#' gg
-#' }
 coastline <- function(year = NULL, ...) {
 
   if (is.null(year)) {
 
-    year <- getOption("tigris_year", 2018)
+    year <- getOption("tigris_year", 2019)
 
   }
 
